@@ -3,7 +3,7 @@ package Net::Async::Slack::Event::BotAdded;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use parent qw(Net::Async::Slack::Event::Bot);
 
@@ -11,17 +11,17 @@ use Net::Async::Slack::EventType;
 
 =head1 DESCRIPTION
 
-{
- "type": "bot_added",
- "bot": {
-  "id": "B024BE7LH",
-  "app_id": "A4H1JB4AZ",
-  "name": "hugbot",
-  "icons": {
-   "image_48": "https:\/\/slack.com\/path\/to\/hugbot_48.png"
-  }
- }
-}
+    {
+     "type": "bot_added",
+     "bot": {
+      "id": "B024BE7LH",
+      "app_id": "A4H1JB4AZ",
+      "name": "hugbot",
+      "icons": {
+       "image_48": "url here"
+      }
+     }
+    }
 
 =cut
 
