@@ -3,7 +3,7 @@ package Net::Async::Slack::Event::ChannelArchive;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use parent qw(Net::Async::Slack::Event::Channel);
 
@@ -23,3 +23,12 @@ sub type { 'channel_archive' }
 
 1;
 
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <TEAM@cpan.org>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
