@@ -3,13 +3,13 @@ package Net::Async::Slack::Event::CommandsChanged;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Net::Async::Slack::EventType;
 
 =head1 NAME
 
-Net::Async::Slack::Event::CommandsChanged - A team slash command has been added or changed
+Net::Async::Slack::Event::CommandsChanged - A slash command has been added or changed
 
 =head1 DESCRIPTION
 
@@ -27,3 +27,12 @@ sub type { 'commands_changed' }
 
 1;
 
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <TEAM@cpan.org>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
