@@ -3,13 +3,13 @@ package Net::Async::Slack::Event::GridMigrationFinished;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Net::Async::Slack::EventType;
 
 =head1 NAME
 
-Net::Async::Slack::Event::GridMigrationFinished - An enterprise grid migration has finished on this team.
+Net::Async::Slack::Event::GridMigrationFinished - An enterprise grid migration has finished on this workspace.
 
 =head1 DESCRIPTION
 
@@ -35,3 +35,12 @@ sub type { 'grid_migration_finished' }
 
 1;
 
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <TEAM@cpan.org>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
