@@ -3,7 +3,7 @@ package Net::Async::Slack::Event::GroupLeft;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Net::Async::Slack::EventType;
 
@@ -15,11 +15,7 @@ Net::Async::Slack::Event::GroupLeft - You left a private channel
 
 Example input data:
 
-    {
-        "type": "group_left",
-        "channel": "G02ELGNBH"
-    }
-
+    groups:read
 
 =cut
 
@@ -27,3 +23,12 @@ sub type { 'group_left' }
 
 1;
 
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <TEAM@cpan.org>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
