@@ -3,21 +3,27 @@ package Net::Async::Slack::Event::ReconnectURL;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
-use Net::Async::Slack::EventType;
+=head1 NAME
+
+Net::Async::Slack::Event::ReconnectURL - Experimental
 
 =head1 DESCRIPTION
 
-{
-"type":"reconnect_url",
-"url":"wss://mpmulti-9w2u.slack-msgs.com/websocket/Sjb...zNIE="
-}
+Example input data:
+
+    {
+        "type": "reconnect_url"
+    }
+
 
 =cut
 
 use URI;
 
+use Net::Async::Slack::EventType;
+
 sub url { shift->{url} }
 
 sub uri { $_[0]->{uri} //= URI->new($_[0]->url) }
