@@ -3,13 +3,13 @@ package Net::Async::Slack::Event::TeamProfileDelete;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Net::Async::Slack::EventType;
 
 =head1 NAME
 
-Net::Async::Slack::Event::TeamProfileDelete - Team profile fields have been deleted
+Net::Async::Slack::Event::TeamProfileDelete - The workspace profile fields have been deleted
 
 =head1 DESCRIPTION
 
@@ -32,3 +32,12 @@ sub type { 'team_profile_delete' }
 
 1;
 
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <TEAM@cpan.org>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
