@@ -3,7 +3,7 @@ package Net::Async::Slack::Event::TokensRevoked;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Net::Async::Slack::EventType;
 
@@ -42,3 +42,12 @@ sub type { 'tokens_revoked' }
 
 1;
 
+__END__
+
+=head1 AUTHOR
+
+Tom Molesworth <TEAM@cpan.org>
+
+=head1 LICENSE
+
+Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
